@@ -41,10 +41,32 @@ module Ohai
     module Ec2Metadata
 
       EC2_METADATA_ADDR ||= "169.254.169.254"
-      EC2_SUPPORTED_VERSIONS ||= %w{ 1.0 2007-01-19 2007-03-01 2007-08-29 2007-10-10 2007-12-15
-                                     2008-02-01 2008-09-01 2009-04-04 2011-01-01 2011-05-01 2012-01-12
-                                     2014-02-25 2014-11-05 2015-10-20 2016-04-19 2016-06-30 2016-09-02
-                                     2016-11-30 2018-08-17 2018-11-29 2019-10-01 2020-08-24 2020-11-01 }.freeze
+      EC2_SUPPORTED_VERSIONS ||= %w{ 1.0
+                                     2007-01-19
+                                     2007-03-01
+                                     2007-08-29
+                                     2007-10-10
+                                     2007-12-15
+                                     2008-02-01
+                                     2008-09-01
+                                     2009-04-04
+                                     2011-01-01
+                                     2011-05-01
+                                     2012-01-12
+                                     2014-02-25
+                                     2014-11-05
+                                     2015-10-20
+                                     2016-04-19
+                                     2016-06-30
+                                     2016-09-02
+                                     2018-03-28
+                                     2018-08-17
+                                     2018-09-24
+                                     2019-10-01
+                                     2020-10-27
+                                     2021-01-03
+                                     2021-03-23
+                                     2021-07-15 }.freeze
       EC2_ARRAY_VALUES ||= %w{security-groups local_ipv4s}.freeze
       EC2_ARRAY_DIR    ||= %w{network/interfaces/macs}.freeze
       EC2_JSON_DIR     ||= %w{iam}.freeze
