@@ -80,7 +80,7 @@ Ohai.plugin(:Network) do
       line.strip!
       logger.trace("Plugin Network: Parsing #{line}")
       if /\\/.match?(line)
-        parts = line.split('\\')
+        parts = line.split("\\")
         route_dest = parts.shift.strip
         route_endings = parts
       elsif line =~ /^([^\s]+)\s(.*)$/
@@ -141,13 +141,13 @@ Ohai.plugin(:Network) do
 
   # using a temporary var to hold routes and their interface name
   def parse_routes(family, iface)
-    iface.collect do |i, iv|
+    iface.filter_map do |i, iv|
       next unless iv[:routes]
 
-      iv[:routes].collect do |r|
+      iv[:routes].filter_map do |r|
         r.merge(dev: i) if r[:family] == family[:name]
-      end.compact # @todo: when we drop ruby 2.6 this should be a filter_map
-    end.compact.flatten # @todo: when we drop ruby 2.6 this should be a filter_map
+      end
+    end.flatten
   end
 
   # determine layer 1 details for the interface using ethtool
@@ -273,6 +273,30 @@ Ohai.plugin(:Network) do
     iface
   end
 
+  # determine offload features for the interface using ethtool
+  def ethernet_offload_parameters(iface)
+    return iface unless ethtool_binary_path
+
+    iface.each_key do |tmp_int|
+      next unless iface[tmp_int][:encapsulation] == "Ethernet"
+
+      so = shell_out("#{ethtool_binary_path} -k #{tmp_int}")
+      Ohai::Log.debug("Plugin Network: Parsing ethtool output: #{so.stdout}")
+      iface[tmp_int]["offload_params"] = {}
+      so.stdout.lines.each do |line|
+        next if line.start_with?("Features for")
+        next if line.strip.nil?
+
+        key, val = line.split(/:\s+/)
+        if val
+          offload_key = key.downcase.strip.tr(" ", "_").to_s
+          iface[tmp_int]["offload_params"][offload_key] = val.downcase.gsub(/\[.*\]/, "").strip.to_s
+        end
+      end
+    end
+    iface
+  end
+
   # determine pause parameters for the interface using ethtool
   def ethernet_pause_parameters(iface)
     return iface unless ethtool_binary_path
@@ -793,6 +817,7 @@ Ohai.plugin(:Network) do
     iface = ethernet_ring_parameters(iface)
     iface = ethernet_channel_parameters(iface)
     iface = ethernet_coalesce_parameters(iface)
+    iface = ethernet_offload_parameters(iface)
     iface = ethernet_driver_info(iface)
     iface = ethernet_pause_parameters(iface)
     counters[:network][:interfaces] = net_counters
