@@ -54,7 +54,7 @@ Ohai.plugin(:Platform) do
   end
 
   #
-  # Cached /etc/os-release info Hash.  Also has logic for Cisco Nexus
+  # Cached /etc/os-release info Hash. Also has logic for Cisco Nexus
   # switches that pulls the chained CISCO_RELEASE_INFO file into the Hash (other
   # distros can also reuse this method safely).
   #
@@ -122,7 +122,7 @@ Ohai.plugin(:Platform) do
       "sles_sap" => "suse",
       "sles" => "suse",
       "xenenterprise" => "xenserver",
-    }[id] || id
+    }[id.downcase] || id.downcase
   end
 
   #
@@ -134,22 +134,24 @@ Ohai.plugin(:Platform) do
   #
   def platform_family_from_platform(plat)
     case plat
-    when /debian/, /ubuntu/, /linuxmint/, /raspbian/, /cumulus/, /kali/, /pop/
+    when /ubuntu/, /debian/, /linuxmint/, /raspbian/, /cumulus/, /kali/, /pop/
       # apt-get+dpkg almost certainly goes here
       "debian"
-    when /oracle/, /centos/, /redhat/, /almalinux/, /scientific/, /enterpriseenterprise/, /xcp/, /xenserver/, /cloudlinux/, /ibm_powerkvm/, /parallels/, /nexus_centos/, /clearos/, /bigip/, /alibabalinux/, /sangoma/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
+    when /centos/, /redhat/, /oracle/, /almalinux/, /rocky/, /scientific/, /enterpriseenterprise/, /xenserver/, /xcp-ng/, /cloudlinux/, /alibabalinux/, /sangoma/, /clearos/, /parallels/, /ibm_powerkvm/, /nexus_centos/, /bigip/, /virtuozzo/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
       # NOTE: "rhel" should be reserved exclusively for recompiled rhel versions that are nearly perfectly compatible down to the platform_version.
       # The operating systems that are "rhel" should all be as compatible as rhel7 = centos7 = oracle7 = scientific7 (98%-ish core RPM version compatibility
       # and the version numbers MUST track the upstream). The appropriate EPEL version repo should work nearly perfectly.  Some variation like the
-      # oracle kernel version differences and tuning and extra packages are clearly acceptable.  Almost certainly some distros above (xenserver?)
-      # should not be in this list.  Please use fedora, below, instead.  Also note that this is the only platform_family with this strict of a rule,
+      # oracle kernel version differences and tuning and extra packages are clearly acceptable. Almost certainly some distros above (xenserver?)
+      # should not be in this list. Please use fedora, below, instead. Also note that this is the only platform_family with this strict of a rule,
       # see the example of the debian platform family for how the rest of the platform_family designations should be used.
+      #
+      # TODO: when XCP-NG 7.4 support ends we can remove the xcp-ng match. 7.5+ reports as xenenterprise which we remap to xenserver
       "rhel"
     when /amazon/
       "amazon"
-    when /suse/, /sles/, /opensuse/, /opensuseleap/, /sled/
+    when /suse/, /sles/, /opensuseleap/, /opensuse/, /sled/
       "suse"
-    when /fedora/, /pidora/, /arista_eos/
+    when /fedora/, /arista_eos/
       # In the broadest sense:  RPM-based, fedora-derived distributions which are not strictly re-compiled RHEL (if it uses RPMs, and smells more like redhat and less like
       # SuSE it probably goes here).
       "fedora"
@@ -157,9 +159,7 @@ Ohai.plugin(:Platform) do
       "wrlinux"
     when /gentoo/
       "gentoo"
-    when /slackware/
-      "slackware"
-    when /arch/, /manjaro/, /antergos/
+    when /arch/, /manjaro/
       "arch"
     when /exherbo/
       "exherbo"
@@ -169,6 +169,8 @@ Ohai.plugin(:Platform) do
       "clearlinux"
     when /mangeia/
       "mandriva"
+    when /slackware/
+      "slackware"
     end
   end
 
@@ -271,9 +273,6 @@ Ohai.plugin(:Platform) do
     elsif /XenServer/i.match?(lsb[:id])
       platform "xenserver"
       platform_version lsb[:release]
-    elsif /XCP/i.match?(lsb[:id])
-      platform "xcp"
-      platform_version lsb[:release]
     elsif lsb[:id] # LSB can provide odd data that changes between releases, so we currently fall back on it rather than dealing with its subtleties
       platform lsb[:id].downcase
       platform_version lsb[:release]
