@@ -20,6 +20,7 @@
 Ohai.plugin(:Virtualization) do
   provides "virtualization"
   depends "dmi"
+  depends "cpu"
   require_relative "../../mixin/dmi_decode"
   include Ohai::Mixin::DmiDecode
 
@@ -35,6 +36,10 @@ Ohai.plugin(:Virtualization) do
     which("docker")
   end
 
+  def podman_exists?
+    which("podman")
+  end
+
   collect_data(:linux) do
     virtualization Mash.new unless virtualization
     virtualization[:systems] ||= Mash.new
@@ -46,6 +51,13 @@ Ohai.plugin(:Virtualization) do
       virtualization[:systems][:docker] = "host"
     end
 
+    # Podman hosts
+    if podman_exists?
+      virtualization[:system] = "podman"
+      virtualization[:role] = "host"
+      virtualization[:systems][:podman] = "host"
+    end
+
     # Xen Notes:
     # - /proc/xen is an empty dir for EL6 + Linode Guests + Paravirt EC2 instances
     # - cpuid of guests, if we could get it, would also be a clue
@@ -115,6 +127,14 @@ Ohai.plugin(:Virtualization) do
         virtualization[:role] = "host"
         virtualization[:systems][:kvm] = "host"
       end
+    elsif get_attribute(:cpu, :hypervisor_vendor)
+      if get_attribute(:cpu, :hypervisor_vendor) == "KVM"
+        virtualization[:system] = "kvm"
+        if /(para|full)/.match?(get_attribute(:cpu, :virtualization_type))
+          virtualization[:role] = "guest"
+          virtualization[:systems][:kvm] = "guest"
+        end
+      end
     end
 
     # parse dmi to discover various virtualization guests
@@ -188,7 +208,7 @@ Ohai.plugin(:Virtualization) do
     # <index #>:<subsystem>:/
     #
     # Full notes, https://tickets.opscode.com/browse/OHAI-551
-    # Kernel docs, https://www.kernel.org/doc/Documentation/cgroups
+    # Kernel docs, https://web.archive.org/web/20100514070914/http://www.kernel.org/doc/Documentation/cgroups/
     if file_exist?("/proc/self/cgroup")
       cgroup_content = file_read("/proc/self/cgroup")
       # These two REs catch many different examples. Here's a specific one
@@ -210,6 +230,20 @@ Ohai.plugin(:Virtualization) do
         virtualization[:system] = "nspawn"
         virtualization[:role] = "guest"
         virtualization[:systems][:nspawn] = "guest"
+      elsif /container=podman/.match?(file_read("/proc/1/environ"))
+        logger.trace("Plugin Virtualization: /proc/1/environ indicates podman container. Detecting as podman guest")
+        virtualization[:system] = "podman"
+        virtualization[:role] = "guest"
+        virtualization[:systems][:podman] = "guest"
+      # Detect any containers that appear to be using docker such as those running on Github Actions virtual machines
+      # but aren't triggered by the cgroup regex above. It's pretty safe to assume if the cgroup contains containerd,
+      # it's likely using docker.
+      # https://rubular.com/r/qhSmV113cPmEBT
+      elsif %r{^\d+:[^:]*:/[^/]+/(containerd)-?.+$}.match?(cgroup_content)
+        logger.trace("Plugin Virtualization: /proc/self/cgroup indicates docker container. Detecting as docker guest")
+        virtualization[:system] = "docker"
+        virtualization[:role] = "guest"
+        virtualization[:systems][:docker] = "guest"
       elsif lxc_version_exists? && file_read("/proc/self/cgroup") =~ %r{\d:[^:]+:/$}
         # lxc-version shouldn't be installed by default
         # Even so, it is likely we are on an LXC capable host that is not being used as such
